<?php
/**
 * End of Day Report
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/emails/pos-end-of-day-report.php.
 *
 * @var WC_POS_Session  $session
 * @var string          $additional_content
 * @var bool            $sent_to_admin
 * @var bool            $plain_text
 * @var WC_Email        $email
 *
 * @package WooCommerce_Point_Of_Sale/Templates/Emails
 */

defined( 'ABSPATH' ) || exit;

$session_id      = $session->get_id();
$counted_totals  = $session->get_counted_totals();
$session_totals  = wc_pos_get_session_totals( $session_id );
$session_details = wc_pos_get_session_details( $session_id );
$text_align      = is_rtl() ? 'right' : 'left';
$datetime_format = wc_date_format() . ' ' . wc_time_format();

$order_table_enabled = 'yes' === get_option( 'wc_pos_end_of_day_email_order_table', 'no' );
$order_table_columns = get_option( 'wc_pos_end_of_day_email_order_table_columns' );
$order_table_columns = empty( $order_table_columns ) ? [ 'number', 'total', 'number_of_items' ] : $order_table_columns;

/**
 * Email header.
 *
 * @since 4.0.0
 */
do_action( 'woocommerce_email_header', $email_heading, $email ); ?>

<p><?php esc_html_e( 'You are receiving this email as a recepient of the end of day reports generated by Point of Sale for WooCommerce.', 'woocommerce-point-of-sale' ); ?></p>

<h2><?php esc_html_e( 'Summary', 'woocommerce-point-of-sale' ); ?></h2>
<table class="td" cellspacing="0" cellpadding="6" style="margin-bottom: 40px; width: 100%; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;" border="1">
	<thead>
		<tr>
			<th class="td" scope="row" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Register', 'woocommerce-point-of-sale' ); ?></th>
			<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $session_details['register'] ); ?></td>
		</tr>
		<tr>
			<th class="td" scope="row" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Outlet', 'woocommerce-point-of-sale' ); ?></th>
			<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $session_details['outlet'] ); ?></td>
		</tr>
		<tr>
			<th class="td" scope="row" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Opened By', 'woocommerce-point-of-sale' ); ?></th>
			<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $session_details['opened_by'] ); ?></td>
		</tr>
		<tr>
			<th class="td" scope="row" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Closed By', 'woocommerce-point-of-sale' ); ?></th>
			<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $session_details['closed_by'] ); ?></td>
		</tr>
		<tr>
			<th class="td" scope="row" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Opened', 'woocommerce-point-of-sale' ); ?></th>
			<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $session->get_date_opened()->date( $datetime_format ) ); ?></td>
		</tr>
		<tr>
			<th class="td" scope="row" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Closed', 'woocommerce-point-of-sale' ); ?></th>
			<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $session->get_date_closed()->date( $datetime_format ) ); ?></td>
		</tr>
		<?php if ( ! empty( $session->get_closing_note() ) ) : ?>
		<tr>
			<th class="td" scope="row" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Closing Note', 'woocommerce-point-of-sale' ); ?></th>
			<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $session->get_closing_note() ); ?></td>
		</tr>
		<?php endif; ?>
		<tr>
			<th class="td" scope="row" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Total Cash Flow', 'woocommerce-point-of-sale' ); ?></th>
			<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo wp_kses_post( wc_price( $session->get_total_cash_flow() ) ); ?></td>
		</tr>
	</thead>
</table>

<?php
$cash_flow = array_filter(
	$session->get_cash_flow(),
	function ( $item ) {
		return 0 !== $item['amount'];
	}
);
?>
<?php if ( ! empty( $cash_flow ) ) : ?>
<h2><?php esc_html_e( 'Cash Movements', 'woocommerce-point-of-sale' ); ?></h2>

<table class="td" cellspacing="0" cellpadding="6" style="margin-bottom: 40px; width: 100%; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;" border="1">
	<thead>
		<tr>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Clerk', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Time', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Amount', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Note', 'woocommerce-point-of-sale' ); ?></th>
		</tr>
	</thead>
	<tbody>
		<?php
		foreach ( $cash_flow as $item ) :
			$clerk  = isset( $item['user'] ) && isset( $item['user']['name'] ) ? $item['user']['name'] : __( 'Deleted User', 'woocommerce-point-of-sale' );
			$time   = date_i18n( $datetime_format, $item['timestamp'] );
			$amount = $item['amount'];
			$note   = $item['note'];
			?>
			<tr>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $clerk ); ?></td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $time ); ?></td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo wp_kses_post( wc_price( $amount ) ); ?></td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $note ); ?></td>
			</tr>
		<?php endforeach; ?>
	</tbody>
</table>

<?php endif; ?>

<h2><?php esc_html_e( 'Payments', 'woocommerce-point-of-sale' ); ?></h2>

<table class="td" cellspacing="0" cellpadding="6" style="margin-bottom: 40px; width: 100%; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;" border="1">
	<thead>
		<tr>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Payment', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Orders', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Total', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Refunds', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Expected', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Counted', 'woocommerce-point-of-sale' ); ?></th>
			<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Difference', 'woocommerce-point-of-sale' ); ?></th>
		</tr>
	</thead>
	<tbody>
		<?php
		foreach ( $session_totals['payments'] as $key => $payment ) :
			// Exclude pending payments orders.
			if ( empty( $key ) ) {
				continue;
			}

			$counted         = isset( $counted_totals[ $key ] ) ? $counted_totals[ $key ] : 0;
			$total_cash_flow = 'pos_cash' === $key ? $session->get_total_cash_flow() : 0;
			$expected        = $payment['total'] - $payment['refunds_total'] + $total_cash_flow;
			$difference      = $counted ? $counted - $expected : 0;
			?>
			<tr>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $payment['title'] ); ?></td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $payment['orders_count'] ); ?></td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo wp_kses_post( wc_price( $payment['total'] ) ); ?></td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo wp_kses_post( wc_price( $payment['refunds_total'] ) ); ?></td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;">
					<?php echo wp_kses_post( wc_price( $expected ) ); ?>
					<?php if ( $total_cash_flow ) : ?>
						<div><em>(<?php echo wp_kses_post( wc_price( $total_cash_flow ) ); ?> <?php esc_html_e( 'opening float', 'woocommerce-point-of-sale' ); ?>)</em></div>
					<?php endif; ?>
				</td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo wp_kses_post( wc_price( $counted ) ); ?></td>
				<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo wp_kses_post( wc_price( $difference ) ); ?></td>
			</tr>
		<?php endforeach; ?>
	</tbody>
</table>

<?php
if ( $order_table_enabled ) :
	$orders = wc_pos_get_session_orders( $session_id );

	$orders = array_filter(
		$orders,
		function ( $order ) {
			return $order->is_paid();
		}
	);

	$orders = array_map(
		function ( $order ) {
			return [
				'number'          => $order->get_order_number(),
				'total'           => $order->get_total(),
				'number_of_items' => $order->get_item_count(),
			];
		},
		$orders
	);

	if ( ! empty( $orders ) ) :
		?>
<h2><?php esc_html_e( 'Orders', 'woocommerce-point-of-sale' ); ?></h2>

<table class="td" cellspacing="0" cellpadding="6" style="margin-bottom: 40px; width: 100%; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;" border="1">
	<thead>
		<tr>
			<?php
			if ( in_array( 'number', $order_table_columns, true ) ) :
				?>
				<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Order Number', 'woocommerce-point-of-sale' ); ?></th><?php endif; ?>
			<?php
			if ( in_array( 'total', $order_table_columns, true ) ) :
				?>
				<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Order Total', 'woocommerce-point-of-sale' ); ?></th><?php endif; ?>
			<?php
			if ( in_array( 'number_of_items', $order_table_columns, true ) ) :
				?>
				<th class="td" scope="col" style="text-align:<?php echo esc_attr( $text_align ); ?>;"><?php esc_html_e( 'Number of Items', 'woocommerce-point-of-sale' ); ?></th><?php endif; ?>
		</tr>
	</thead>
	<tbody>
		<?php
		foreach ( $orders as $shop_order ) :
			// TODO: exclude pending payment orders.
			?>
			<tr>
				<?php
				if ( in_array( 'number', $order_table_columns, true ) ) :
					?>
					<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;">#<?php echo esc_html( $shop_order['number'] ); ?></td><?php endif; ?>
				<?php
				if ( in_array( 'total', $order_table_columns, true ) ) :
					?>
					<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo wp_kses_post( wc_price( $shop_order['total'] ) ); ?></td><?php endif; ?>
				<?php
				if ( in_array( 'number_of_items', $order_table_columns, true ) ) :
					?>
					<td class="td" style="text-align:<?php echo esc_attr( $text_align ); ?>; vertical-align:middle; font-family: 'Helvetica Neue', Helvetica, Roboto, Arial, sans-serif;"><?php echo esc_html( $shop_order['number_of_items'] ); ?></td><?php endif; ?>
			</tr>
		<?php endforeach; ?>
	</tbody>
</table>
		<?php
	endif;
endif;
?>

<?php
/**
 * Email footer.
 *
 * @since 4.0.0
 */
do_action( 'woocommerce_email_footer', $email );
?>